@@ -330,7 +330,7 @@ nm_sbrsh_setup_apply_changes (NmConnWidget *self)
         gchar *concat_list = g_strdup("");
         int i;
         for (i = 0; i < length; i++) {
-            concat_list = g_strconcat(concat_list, " ", list[i], NULL);
+            concat_list = g_strconcat(concat_list, " '", list[i], "'", NULL);
         }
         
         g_debug("[%s] - concat_list: %s", __FUNCTION__, concat_list);
